@@ -1,4 +1,4 @@
-class Collector with Active, Buyer {
+class Collector with Buyer {
     has money! ( type => Num );
     # Actually an ArrayRef of Artworks
     has collection (
