@@ -1,14 +1,14 @@
-package Art::World;
-
 use v5.32;
+use utf8;
+package Art::World;
 
 
 # use Art::Agent;
 #has Art::Agent::Artist @.artists;
 
-our $VERSION = '0.08';
+our $VERSION = '0.15';
 
-=begin pod
+1;
 
 =encoding UTF-8
 
@@ -124,4 +124,4 @@ Copyright 2006-2020 Seb. Hu-Rillettes
 
 This library is free software; you can redistribute it and/or modify it under the Artistic License 2.0.
 
-=end pod
+=cut
